--[[
LuCI - Lua Configuration Interface
]]--

local taskd = require "luci.model.tasks"
local jitsi_model = require "luci.model.jitsi"
local m, s, o

m = taskd.docker_map("jitsi", "jitsi", "/usr/libexec/apps/jitsi/jitsi.sh",
	translate("jitsi"),
	translate("More secure, more flexible, and completely free video conferencing.")
		.. translate("Official website:") .. ' <a href=\"https://www.jitsi.org/\" target=\"_blank\">https://www.jitsi.org/</a>')

s = m:section(SimpleSection, translate("Service Status"), translate("jitsi status:"))
s:append(Template("jitsi/status"))

s = m:section(TypedSection, "jitsi", translate("Setup"), translate("Refresh to update settings."))
s.addremove=false
s.anonymous=true

o = s:option(Value, "port", translate("Port").."<b>*</b>")
o.rmempty = false
o.default = "8443"
o.datatype = "port"

o = s:option(Value, "image_name", translate("Version").."<b>*</b>")
o.rmempty = false
o.datatype = "string"
o:value("stable-8319", "stable-8319")
o.default = "stable-8319"

o = s:option(Value, "username", translate("Jitsi Admin Username"))
o.rmempty = false
o.datatype = "string"

o = s:option(Value, "password", translate("Jitsi Admin Password"))
o.rmempty = false
o.datatype = "string"
o.password = true

o = s:option(Value, "domain", translate("Public Jitsi domain"))
o.rmempty = false
o.datatype = "string"

o = s:option(Value, "wireguard", translate("WireGuard VPN IP"))
o.rmempty = false
o.datatype = "string"

local blocks = jitsi_model.blocks()
local home = jitsi_model.home()

o = s:option(Value, "config_path", translate("Install path").."<b>*</b>")
o.rmempty = false
o.datatype = "string"
o:value("/opt/docker2/compose/jitsi", "/opt/docker2/compose/jitsi")
o.default = "/opt/docker2/compose/jitsi"

local paths, default_path = jitsi_model.find_paths(blocks, home, "Configs")
for _, val in pairs(paths) do
  o:value(val, val)
end
o.default = default_path

return m
